<template>
    <el-dialog
        :visible.sync="specialPersonFormVisible"
        append-to-body
        :title="title"
        :close-on-click-modal="false"
        width="600px"
    >
        <el-form ref="dataForm" :rules="dataFormRules" :model="dataForm" label-position="right" label-width="140px"  width="600px">
            <el-form-item label="姓名:" prop="name" >
                <el-input v-model="dataForm.name" width="150px"/>
            </el-form-item>
            <el-form-item label="职务:" prop="post">
                <el-input v-model="dataForm.post"/>
            </el-form-item>
            <el-form-item label="特种作业操作证号:" prop="number">
                <el-input v-model="dataForm.number"/>
            </el-form-item>
            <el-form-item label="培训合格证有效期:" prop="validTime">
                <el-date-picker
                    value-format="yyyy-MM-dd"
                    v-model="validTime"
                    type="daterange"
                    range-separator="至"
                    start-placeholder="开始日期"
                    end-placeholder="结束日期"
                    @change="giveData"
                >
                </el-date-picker>
            </el-form-item>
            <el-form-item label="是否按时复审:" prop="isreview">
                <el-select v-model="dataForm.isreview">
                    <el-option
                    v-for="item in isReviewList"
                    :label="item.name"
                    :value="item.text"
                    :key="item.id"
                    ></el-option>
                </el-select>
            </el-form-item>
            <!--            <el-form-item label="许可范围:" prop="ranges">-->
            <!--                <template slot-scope="scope">-->
            <!--                    <img v-for="(item,index) in scope.row.enterprisesource"></img>-->
            <!--                </template>-->
            <!--            </el-form-item>-->
            <el-form-item label="证件照片:" prop="directionCode">
                <input id="upload" ref="upload"  type="file" accept="image/*" multiple/>
            </el-form-item>
            <el-form-item label="备注:" prop="memo">
                <el-input v-model="dataForm.memo"/>
            </el-form-item>
        </el-form>
        <div  align="right">
            <el-button @click="permitFormVisible = false">取消</el-button>
            <el-button type="primary" @click="submitPermit()">确认</el-button>
        </div>
    </el-dialog>

</template>

<script>
import { getToken } from '@/utils/auth'
import { addSafetyPersonQualification ,updateSafetyPersonQualification  } from "../../../../api/safetyPersonQualification";

export default {
    name: "permitForm",
    data(){
        return{
            title:'',
            validTime:['',''],
            specialPersonFormVisible:false,
            header:{
                'Authorization': getToken()
            },
            enterpriseId:'',
            dataForm:{
                file: [
                ],
                id: 0,
                imgids: [
                ],
                memo: "",
                name: "",
                number: "",
                other: "",
                post: "",
                isreview:"",
                type: "SPECIAL",
                validendtime: "",
                validstarttime: ""
            },
            isReviewList:[{id:0,name:'否',text:false},{id:1,name:'是',text:true}],
            dataFormRules:{},
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            dialogImageUrl: '',
            dialogVisible: false,
            disabled: false,
            fileList:[],
            uploadData:{
                enterprise:1
            },
        }
    },
    methods:{
        showSpecialPersonForm(title,value,enterpriseId){
            this.enterpriseId = enterpriseId
            this.specialPersonFormVisible = true
            this.title = title
            if(this.title === '新增'){
                this.validTime = ['','']
                this.dataForm = {
                    file: [
                    ],
                    id: 0,
                    imgids: [
                    ],
                    memo: "",
                    name: "",
                    number: "",
                    other: "",
                    post: "",
                    type: "SPECIAL",
                    isreview:'',
                    validendtime: "",
                    validstarttime: ""
                }
            }else{
                this.dataForm.id = value.id
                if(value.validstarttime === null && value.validendtime === null){
                    this.validTime = ['','']
                }else{
                    this.validTime = [value.validstarttime, value.validendtime]
                }
                this.dataForm.file=[]
                this.dataForm.imgids = []
                this.dataForm.id = value.id
                this.dataForm.memo = value.memo
                this.dataForm.name = value.name
                this.dataForm.number = value.number
                this.dataForm.other = value.other
                this.dataForm.post = value.post
                this.dataForm.isreview = value.isreview
                this.dataForm.validendtime = value.validendtime
                this.dataForm.validstarttime = value.validstarttime
                for(let i = 0;i<value.enterpriseResources.length;i++){
                    this.dataForm.imgids.push(value.enterpriseResources[i].id)
                }
            }
        },
        async submitPermit(){
            this.dataForm.type = "SPECIAL"
            const formData = new FormData();
            if(this.$refs["upload"].files.length === 0){
                this.dataForm.imgids = []
            }
            for (const i in this.dataForm) {
                if (
                    this.dataForm[i] != undefined &&
                    this.dataForm[i].toString() != ""
                ) {
                    formData.append(i, this.dataForm[i]);
                }
            }
            formData.append("enterpriseid",this.enterpriseId)

            const files1 = this.$refs["upload"].files;
            if (files1 && files1.length > 0) {
                for (let i = 0; i < files1.length; i++)
                    formData.append("file", files1[i]);
            }

            // formData.append("file", this.$refs["upload"].files);
            if(this.title === '新增'){
                let res = await addSafetyPersonQualification(formData)
                if(res.data.code === "200"){
                    this.$refs["upload"].value = ''
                    this.$emit('getinfo')
                    this.specialPersonFormVisible = false
                    this.$notify({
                        type:'success',
                        duration:2000,
                        message:'成功',
                        title:'成功',
                    })
                }else {
                    this.$message({
                        type:'warning',
                        message:res.data.message
                    })
                }
            }else{
                let res = await updateSafetyPersonQualification(formData)
                if(res.data.code === "200") {
                    this.$refs["upload"].value = ''
                    this.$emit('getinfo')
                    this.specialPersonFormVisible = false
                    this.$notify({
                        type: 'success',
                        duration: 2000,
                        message: '成功',
                        title: '成功',
                    })
                }else{
                    this.$message({
                        type:'warning',
                        message:res.data.message
                    })
                }
            }
        },
        giveData(){
            if(this.validTime === null){
                this.dataForm.validstarttime=""
                this.dataForm.validendtime=""
            }else{
                this.dataForm.validstarttime = this.validTime[0]
                this.dataForm.validendtime = this.validTime[1]
            }

        }
    }
}
</script>

<style scoped>
/deep/ .el-input__inner {
    width:300px;
}
</style>
